#include "orbsvcs/LoadBalancing/LB_LoadAlertInfo.h"
#include "orbsvcs/PortableGroup/PG_Operators.h"

ACE_RCSID (LoadBalancing,
           LB_LoadAlertInfo,
           "$Id: LB_LoadAlertInfo.cpp 71526 2006-03-14 06:14:35Z jtc $")

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_LB_LoadAlertInfo::TAO_LB_LoadAlertInfo (void)
  : load_alert (),
    alerted (0)
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
